@@ -2,8 +2,8 @@ import _ from 'lodash';
 import alertDef from '../../../features/alerting/state/alertDef';
 import { PanelCtrl } from 'app/plugins/sdk';
 
-import { dateMath } from '@grafana/data';
-import { dateTime } from '@grafana/data';
+import { dateMath, dateTime } from '@grafana/data';
+import { PanelEvents } from '@grafana/data';
 import { auto } from 'angular';
 import { BackendSrv } from '@grafana/runtime';
 
@@ -42,8 +42,8 @@ class AlertListPanel extends PanelCtrl {
     super($scope, $injector);
     _.defaults(this.panel, this.panelDefaults);
 
-    this.events.on('init-edit-mode', this.onInitEditMode.bind(this));
-    this.events.on('refresh', this.onRefresh.bind(this));
+    this.events.on(PanelEvents.editModeInitialized, this.onInitEditMode.bind(this));
+    this.events.on(PanelEvents.refresh, this.onRefresh.bind(this));
     this.templateSrv = this.$injector.get('templateSrv');
 
     for (const key in this.panel.stateFilter) {
